<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>EllipseRR</name>
    <message>
        <location filename="../EllipseRR.ui" line="+17"/>
        <location filename="../EllipseRRDialog.ui" line="+129"/>
        <source>X Radius:</source>
        <translation>X半径:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../EllipseRRDialog.ui" line="-10"/>
        <source>Y Radius:</source>
        <translation>Y半径:</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../EllipseRRDialog.ui" line="-90"/>
        <source>Angle:</source>
        <translation>角度:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>基準点:</translation>
    </message>
    <message>
        <location filename="../EllipseRRInit.js" line="+2"/>
        <source>Ellipse with &amp;Radii</source>
        <translation>半径指定の楕円</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw ellipse with position and radii</source>
        <translation>位置と半径を指定して楕円を描く</translation>
    </message>
</context>
</TS>
